Crate solana_stream_sdk

Crate solana_stream_sdk 

Solana Stream SDK

A Rust SDK for streaming Solana data using Shreds and gRPC. This crate provides convenient wrappers around the Shreds protobuf definitions for easier integration with Solana streaming services.

Re-exports

pub use error::SolanaStreamError;
pub use shredstream::ShredstreamClient;
pub use shreds_udp::deshred_shreds_to_entries;
pub use shreds_udp::UdpDatagram;
pub use shreds_udp::UdpShredReceiver;
pub use shredstream_proto::CommitmentLevel;
pub use shredstream_proto::SubscribeEntriesRequest;
pub use shredstream_proto::SubscribeRequestFilterAccounts;
pub use shredstream_proto::SubscribeRequestFilterAccountsFilter;
pub use shredstream_proto::SubscribeRequestFilterAccountsFilterLamports;
pub use shredstream_proto::SubscribeRequestFilterAccountsFilterMemcmp;
pub use shredstream_proto::SubscribeRequestFilterSlots;
pub use shredstream_proto::SubscribeRequestFilterTransactions;
pub use yellowstone_grpc_client;
pub use yellowstone_grpc_proto;

Modules

error
shared
shreds_udp
shredstream
Shredstream client wrapper
shredstream_proto
txn

Structs

GeyserAccountsDataSlice
GeyserFilteredUpdate
GeyserGrpcClient
GeyserGrpcInnerClient
GeyserMessageAccount
GeyserMessageBlock
GeyserMessageBlockMeta
GeyserMessageEntry
GeyserMessageSlot
GeyserMessageTransaction
GeyserSubscribeRequest
GeyserSubscribeRequestFilterAccounts
GeyserSubscribeRequestFilterAccountsFilter
GeyserSubscribeRequestFilterAccountsFilterLamports
GeyserSubscribeRequestFilterAccountsFilterMemcmp
GeyserSubscribeRequestFilterBlocks
GeyserSubscribeRequestFilterBlocksMeta
GeyserSubscribeRequestFilterEntry
GeyserSubscribeRequestFilterSlots
GeyserSubscribeRequestFilterTransactions
GeyserSubscribeUpdate
GeyserSubscribeUpdateAccountInfo
GeyserSubscribeUpdateEntry
GeyserSubscribeUpdateTransactionInfo
GeyserUpdateBlock
GeyserUpdateBlockMeta
GeyserUpdateSlot

Enums

GeyserAccountsFilterEnum
GeyserCommitmentLevel
GeyserGrpcClientError
GeyserLamportsCmp
GeyserMemcmpData
GeyserSlotStatus
GeyserUpdateOneof

Traits

GeyserMessage
A Protocol Buffers message.
Interceptor
A gRPC interceptor.

Type Aliases

Result

Derive Macros

GeyserMessage